package com.qihoo.antivirus.update;

import com.qihoo.antivirus.update.UpdateFileInfo;

interface IUpdateCallback {

    /**
     * 检查更新中返回需要更新的文件列表
     * @param fileNameList 需要更新的文件信息
     * @param totalSize 需要更新的文件总大小
     * @param errorCode 若更新失败，返回失败Code，以16进制编码
     */
    void OnFileUpdate(inout List<UpdateFileInfo> fileNameList, long totalSize, String errorCode);

    /**
     * 开始下载的文件名称
     * @param fileName 需要更新的文件名
     */
    void OnFileDownloadingBegin(String fileName);

    /**
     * 当前正在下载的文件进度，至多每1s回调一次
     * @param fileName 需要更新的文件名
     * @param fileSize 当前更新文件已下载的大小
     * @param fileTotalSize 当前更新文件的总大小
     */
    void OnFileDownloadingProgress(String fileName, long fileSize, long fileTotalSize);

    /**
     * 由于下载失败，非断网失败的回调重试次数
     * @param fileName 需要更新的文件名
     * @param retries 当前重试次数
     * @param maxRetries 最大重试次数
     */
    void OnFileDownloadingRetry(String fileName, int retries, int maxRetries);

    /**
     * 文件下载完成回调
     * @param fileName 需要更新的文件名
     * @param downloadSize 已下载总大小
     * @param totalSize 需要下载文件的总大小
     */
    void OnFileDownloadingEnd(String fileName, long downloadSize, long totalSize);

    /**
     * 下载发生错误的回调函数，当发生错误时取消后续所有的文件下载
     * @param fileName 需要更新的文件名
     * @param errorCode 文件下载错误代码
     * @param errorMessage 文件下载错误描述信息
     */
    void OnError(String fileName, int errorCode, String errorMessage);

    /**
     * 文件普通更新方式回调, 默认新文件放在files下，如需其他地址可业务自行处理
     * @param path 已完成更新拷贝的文件名路径
     * @param hasError 当前文件更新是否发生了错误
     */
    void OnDataFileUpdated(String path, boolean hasError);

    /**
     * Patch文件需要外部处理的通知回调接口
     * @param local 本地文件路径
     * @param patch patch文件路径
     * @param version patch文件版本号
     * @param flag patch文件flag
     * @param method patch文件合并方法
     * @param patchType patch合并类型
     */
    void OnDataFilePatch(String local, String patch, int version, int flag, int method, int patchType);

    /**
     * 所有文件更新完成结束
     * @param hasError 当前更新下载是否存在问题，
     */
    void OnFileUpdateComplete(boolean hasError);
}
